==> ivtv-1.0.3.tar.gz: ivtv-1.0.3/utils/v4l2-chipids.cpp <==
struct chipid { const char *name; unsigned id; } chipids[] = {
{ "none", 0 },
{ "ambiguous", 1 },
{ "unknown", 2 },
{ "tvaudio", 50 },
{ "saa7110", 100 },
{ "saa7111", 101 },
{ "saa7113", 103 },
{ "saa7114", 104 },
{ "saa7115", 105 },
{ "saa7118", 108 },
{ "saa7127", 157 },
{ "saa7129", 159 },
{ "cx25836", 236 },
{ "cx25837", 237 },
{ "cx25840", 240 },
{ "cx25841", 241 },
{ "cx25842", 242 },
{ "cx25843", 243 },
{ "ov7670", 250 },
{ "cx23415", 415 },
{ "cx23416", 416 },
{ "wm8739", 8739 },
{ "wm8775", 8775 },
{ "cs53", 53132 },
{ "upd64031a", 64031 },
{ "upd64083", 64083 },
{ "msp3400b", 34002 },
{ "msp3410b", 34102 },
{ "msp3400c", 34003 },
{ "msp3410c", 34103 },
{ "msp3400d", 34004 },
{ "msp3410d", 34104 },
{ "msp3405d", 34054 },
{ "msp3415d", 34154 },
{ "msp3407d", 34074 },
{ "msp3417d", 34174 },
{ "msp3400g", 34007 },
{ "msp3410g", 34107 },
{ "msp3420g", 34207 },
{ "msp3430g", 34307 },
{ "msp3440g", 34407 },
{ "msp3450g", 34507 },
{ "msp3460g", 34607 },
{ "msp3401g", 34017 },
{ "msp3411g", 34117 },
{ "msp3421g", 34217 },
{ "msp3431g", 34317 },
{ "msp3441g", 34417 },
{ "msp3451g", 34517 },
{ "msp3461g", 34617 },
{ "msp3402g", 34027 },
{ "msp3412g", 34127 },
{ "msp3422g", 34227 },
{ "msp3442g", 34427 },
{ "msp3452g", 34527 },
{ "msp3405g", 34057 },
{ "msp3415g", 34157 },
{ "msp3425g", 34257 },
{ "msp3435g", 34357 },
{ "msp3445g", 34457 },
{ "msp3455g", 34557 },
{ "msp3465g", 34657 },
{ "msp3407g", 34077 },
{ "msp3417g", 34177 },
{ "msp3427g", 34277 },
{ "msp3437g", 34377 },
{ "msp3447g", 34477 },
{ "msp3457g", 34577 },
{ "msp3467g", 34677 },
{ "msp4400g", 44007 },
{ "msp4410g", 44107 },
{ "msp4420g", 44207 },
{ "msp4440g", 44407 },
{ "msp4450g", 44507 },
{ "msp4408g", 44087 },
{ "msp4418g", 44187 },
{ "msp4428g", 44287 },
{ "msp4448g", 44487 },
{ "msp4458g", 44587 },
{ 0, 0 }};

==> ivtv_1.2.0.orig.tar.gz: ivtv-1.2.0/utils/v4l2-chipids.cpp <==
struct chipid { const char *name; unsigned id; } chipids[] = {
{ "none", 0 },
{ "ambiguous", 1 },
{ "unknown", 2 },
{ "tvaudio", 50 },
{ "saa7110", 100 },
{ "saa7111", 101 },
{ "saa7113", 103 },
{ "saa7114", 104 },
{ "saa7115", 105 },
{ "saa7118", 108 },
{ "saa7127", 157 },
{ "saa7129", 159 },
{ "cx25836", 236 },
{ "cx25837", 237 },
{ "cx25840", 240 },
{ "cx25841", 241 },
{ "cx25842", 242 },
{ "cx25843", 243 },
{ "ov7670", 250 },
{ "cx23415", 415 },
{ "cx23416", 416 },
{ "cx23418", 418 },
{ "vp27smpx", 2700 },
{ "cs5345", 5345 },
{ "wm8739", 8739 },
{ "wm8775", 8775 },
{ "cs53", 53132 },
{ "upd64031a", 64031 },
{ "upd64083", 64083 },
{ "m52790", 52790 },
{ "msp3400b", 34002 },
{ "msp3410b", 34102 },
{ "msp3400c", 34003 },
{ "msp3410c", 34103 },
{ "msp3400d", 34004 },
{ "msp3410d", 34104 },
{ "msp3405d", 34054 },
{ "msp3415d", 34154 },
{ "msp3407d", 34074 },
{ "msp3417d", 34174 },
{ "msp3400g", 34007 },
{ "msp3410g", 34107 },
{ "msp3420g", 34207 },
{ "msp3430g", 34307 },
{ "msp3440g", 34407 },
{ "msp3450g", 34507 },
{ "msp3460g", 34607 },
{ "msp3401g", 34017 },
{ "msp3411g", 34117 },
{ "msp3421g", 34217 },
{ "msp3431g", 34317 },
{ "msp3441g", 34417 },
{ "msp3451g", 34517 },
{ "msp3461g", 34617 },
{ "msp3402g", 34027 },
{ "msp3412g", 34127 },
{ "msp3422g", 34227 },
{ "msp3442g", 34427 },
{ "msp3452g", 34527 },
{ "msp3405g", 34057 },
{ "msp3415g", 34157 },
{ "msp3425g", 34257 },
{ "msp3435g", 34357 },
{ "msp3445g", 34457 },
{ "msp3455g", 34557 },
{ "msp3465g", 34657 },
{ "msp3407g", 34077 },
{ "msp3417g", 34177 },
{ "msp3427g", 34277 },
{ "msp3437g", 34377 },
{ "msp3447g", 34477 },
{ "msp3457g", 34577 },
{ "msp3467g", 34677 },
{ "msp4400g", 44007 },
{ "msp4410g", 44107 },
{ "msp4420g", 44207 },
{ "msp4440g", 44407 },
{ "msp4450g", 44507 },
{ "msp4408g", 44087 },
{ "msp4418g", 44187 },
{ "msp4428g", 44287 },
{ "msp4448g", 44487 },
{ "msp4458g", 44587 },
{ "mt9m001c12st", 45000 },
{ "mt9m001c12stm", 45005 },
{ "mt9v022ix7atc", 45010 },
{ "mt9v022ix7atm", 45015 },
{ 0, 0 }};
